#
# spec file for package kaddressbook
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define kf5_version 5.60.0
# Latest stable Applications (e.g. 17.08 in KA, but 17.11.80 in KUA)
%{!?_kapp_version: %define _kapp_version %(echo %{version}| awk -F. '{print $1"."$2}')}
%bcond_without lang
Name:           kaddressbook
Version:        20.04.2
Release:        bp153.2.2.1
Summary:        Address book application to manage contacts
License:        LGPL-2.1-or-later AND GPL-2.0-or-later
Group:          Productivity/Networking/Email/Utilities
URL:            https://www.kde.org
Source:         https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz
BuildRequires:  fdupes
BuildRequires:  gettext-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  cmake(KF5Akonadi)
BuildRequires:  cmake(KF5AkonadiSearch)
BuildRequires:  cmake(KF5Crash)
BuildRequires:  cmake(KF5DBusAddons)
BuildRequires:  cmake(KF5DocTools)
BuildRequires:  cmake(KF5GrantleeTheme)
BuildRequires:  cmake(KF5KCMUtils)
BuildRequires:  cmake(KF5KdepimDBusInterfaces)
BuildRequires:  cmake(KF5KontactInterface)
BuildRequires:  cmake(KF5Libkdepim)
BuildRequires:  cmake(KF5Libkleo)
BuildRequires:  cmake(KF5PimCommon)
BuildRequires:  cmake(KF5PimTextEdit)
BuildRequires:  cmake(KF5Prison)
BuildRequires:  cmake(Qt5DBus) >= 5.2.0
BuildRequires:  cmake(Qt5Gui) >= 5.2.0
BuildRequires:  cmake(Qt5PrintSupport) >= 5.2.0
BuildRequires:  cmake(Qt5Test) >= 5.2.0
BuildRequires:  cmake(Qt5Widgets) >= 5.2.0
Requires:       kdepim-runtime
Recommends:     %{name}-doc
Recommends:     %{name}-lang
Provides:       kaddressbook5 = %{version}
Obsoletes:      kaddressbook5 < %{version}
# It can only build on the same platforms as Qt Webengine
ExclusiveArch:  %{ix86} x86_64 %{arm} aarch64 mips mips64
%if %{with lang}
Source1:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif

%description
KAddressbook is an application by KDE to manage contacts.

%package doc
Summary:        Documentation for kaddressbook
Group:          Documentation/HTML
BuildArch:      noarch

%description doc
This package includes the user guide for KAddressbook in HTML format.

%lang_package

%prep
%setup -q

%build
%cmake_kf5 -d build
%cmake_build

%install
%kf5_makeinstall -C build
%if %{with lang}
  %find_lang %{name} --with-man --all-name
  %{kf5_find_htmldocs}
%endif

%post   -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files doc
%license COPYING COPYING.LIB COPYING.DOC
%doc %lang(en) %{_kf5_htmldir}/en/kaddressbook/

%files
%license COPYING COPYING.LIB COPYING.DOC
%{_kf5_debugdir}/kaddressbook.categories
%{_kf5_debugdir}/kaddressbook.renamecategories
%dir %{_kf5_appstreamdir}/
%{_kf5_applicationsdir}/kaddressbook-importer.desktop
%{_kf5_applicationsdir}/org.kde.kaddressbook*.desktop
%{_kf5_appstreamdir}/org.kde.kaddressbook.appdata.xml
%{_kf5_bindir}/kaddressbook
%{_kf5_iconsdir}/hicolor/*/apps/kaddressbook.png
%{_kf5_iconsdir}/hicolor/scalable/apps/kaddressbook.svg
%{_kf5_libdir}/libkaddressbookprivate.so.*
%{_kf5_plugindir}/kaddressbook_config_plugins.so
%{_kf5_plugindir}/kaddressbookpart.so
%{_kf5_plugindir}/kontact_kaddressbookplugin.so
%{_kf5_servicesdir}/kaddressbook_config_plugins.desktop
%{_kf5_servicesdir}/kaddressbookpart.desktop
%{_kf5_servicesdir}/kontact/
%{_kf5_sharedir}/kaddressbook/
%{_kf5_sharedir}/kconf_update/
%{_kf5_sharedir}/kontact/

%if %{with lang}
%files lang -f %{name}.lang
%license COPYING*
%endif

%changelog
* Tue Jun  9 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-06-apps-update
- No code change since 20.04.1
* Fri May 22 2020 Yunhe Guo <i@guoyunhe.me>
- Change kaddressbook-doc to noarch
* Fri May 15 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-05-apps-update
- No code change since 20.04.0
* Thu Apr 23 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-04-apps-update
- Changes since 20.03.90:
  * Use QLatin1Char('/') here
  * Inform when loading settings was done
  * Fix show config dialog in kontact app
* Sun Apr  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.03.90
  * New feature release
- Changes since 20.03.80:
  * Fix clazy warning
  * Fix cppcheck warning
* Sun Mar 22 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.03.80
  * New feature release
- Too many changes to list here.
* Thu Mar  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-03-apps-update
- No code change since 19.12.2
* Fri Feb  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%make_jobs with %%cmake_build.
* Wed Feb  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-02-apps-update
- No code change since 19.12.1
* Tue Jan 14 2020 Christophe Giboudeaux <christophe@krop.fr>
- Drop the unneeded python2 requirement.
* Tue Jan  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 19.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/releases/19.12.1
- Changes since 19.12.0:
  * Update Appstream for new release
* Tue Dec 10 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/releases/19.12
- Changes since 19.11.90:
  * Update Appstream for new release
* Sat Nov 30 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.11.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/19.12-rc
- No code change since 19.11.80
* Sun Nov 24 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.11.80
  * New feature release
- Changes since 19.08.3:
  * Don't add a non-existent icon search path
  * fix typo 'Pint' -> 'Print'
  * Fix minor typos
  * Add missing CMakeLists.txt
  * Use the new offline documentation
  * Adding new .docbook for KAddressBook, draft version (kde#409998)
  * Fix hidpi support
  * Use QLatin1String in join/startswith/endsWith/contains + QString::replace operates on the same object, no need to reassign
  * QString::replace operates on the same object, no need to reassign
  * Add info about kde release version too.
* Thu Nov  7 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.3.php
- No code change since 19.08.2
* Fri Oct 11 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.2.php
- No code change since 19.08.1
* Thu Sep  5 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.1.php
- No code change since 19.08.0
* Fri Aug  9 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 19.08.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.0.php
- No code change since 19.07.90
* Tue Aug  6 2019 lbeltrame@kde.org
- Update to 19.07.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08-rc.php
- No code changes since 19.07.80
* Tue Jul 23 2019 lbeltrame@kde.org
- Update to 19.07.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08-beta.php
- Changes since 19.04.3:
  * Too many changes to list here
* Fri Jul 19 2019 Christophe Giboudeaux <christophe@krop.fr>
- Use %%_kf5_debugdir for logging categories.
* Sat Jul 13 2019 lbeltrame@kde.org
- Update to 19.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.3.php
- No code changes since 19.04.2
* Fri Jun  7 2019 lbeltrame@kde.org
- Update to 19.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.2.php
- No code changes since 19.04.1
* Fri May 10 2019 lbeltrame@kde.org
- Update to 19.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.1.php
- No code changes since 19.04.0
* Sat Apr 20 2019 lbeltrame@kde.org
- Update to 19.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.0.php
- No code changes since 19.03.90
* Tue Apr  9 2019 lbeltrame@kde.org
- Update to 19.03.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/announce-applications-19.04-rc.php
- Changes since 19.03.80:
  * Convert to camelcase include
  * Workaround qt5.13 bug
* Wed Mar 27 2019 lbeltrame@kde.org
- Update to 19.03.80
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/announce-applications-19.04-beta.php
- Changes since 18.12.3:
  * Too many changes to list here
* Sat Mar  9 2019 lbeltrame@kde.org
- Update to 18.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.3.php
- Changes since 18.12.2:
  * No code changes since 18.12.2
* Sat Feb  9 2019 lbeltrame@kde.org
- Update to 18.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.2.php
- Changes since 18.12.1:
  * No code changes since 18.12.1
* Fri Jan 11 2019 lbeltrame@kde.org
- Update to 18.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.1.php
- Changes since 18.12.0:
  * No code changes since 18.12.0
* Fri Dec 14 2018 lbeltrame@kde.org
- Update to 18.12.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.0.php
- Changes since 18.11.90:
  * No code changes since 18.11.90
* Mon Dec  3 2018 lbeltrame@kde.org
- Update to 18.11.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12-rc.php
- Changes since 18.11.80:
  * No code changes since 18.11.80
* Tue Nov 20 2018 Luca Beltrame <lbeltrame@kde.org>
- Run spec-cleaner
* Tue Nov 20 2018 lbeltrame@kde.org
- Update to 18.11.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12-beta.php
- Changes since 18.08.3:
  * Too many changes to list here
* Thu Nov  8 2018 lbeltrame@kde.org
- Update to 18.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.3.php
- Changes since 18.08.2:
  * No code changes since 18.08.2
* Thu Oct 11 2018 lbeltrame@kde.org
- Update to 18.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.2.php
- Changes since 18.08.1:
  * None
* Thu Sep  6 2018 lbeltrame@kde.org
- Update to 18.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.1.php
- Changes since 18.08.0:
  * None
* Thu Aug 16 2018 christophe@krop.fr
- Update to 18.08.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.0.php
- Changes since 18.07.80:
  * Fix filter checkcombobox
* Thu Jul 26 2018 lbeltrame@kde.org
- Update to 18.07.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08-beta.php
- Changes since 18.04.3:
  * Fix restore to default
  * Increase version
  * Warning--
  * Fix manager leak
  * Use a better icon for the Kontact plugin
  * mainwidget: Add space after "Search..."
* Fri Jul 13 2018 lbeltrame@kde.org
- Update to 18.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.3.php
- Changes since 18.04.2:
  * None
* Fri Jun  8 2018 lbeltrame@kde.org
- Update to 18.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.2.php
- Changes since 18.04.1:
  * None
* Fri May 11 2018 lbeltrame@kde.org
- Update to 18.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.1.php
- Changes since 18.04.0:
  * Fix manager leak
* Wed Apr 18 2018 lbeltrame@kde.org
- Update to 18.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.0.php
- Changes since 18.03.90:
  * None
* Fri Apr  6 2018 lbeltrame@kde.org
- Update to 18.03.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04-rc.php
- Changes since 17.12.3:
  * Too many changes to list here
* Thu Mar  8 2018 lbeltrame@kde.org
- Update to 17.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.3.php
- Changes since 17.12.2:
  * None
* Wed Feb  7 2018 lbeltrame@kde.org
- Update to 17.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.2.php
- Changes since 17.12.1:
  * None
* Thu Jan 11 2018 lbeltrame@kde.org
- Update to 17.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.1.php
- Changes since 17.12.0:
  * None
* Sat Dec  9 2017 lbeltrame@kde.org
- Update to 17.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.0.php
- Changes since 17.11.90:
  * None
* Sat Dec  2 2017 lbeltrame@kde.org
- Update to 17.11.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12-rc.php
- Changes since 17.11.80:
  * Revert this changes. We can add KDEPIM_DEV_VERSION so I don't understand why it was removed. Or it was necessary to remove KDEPIM_DEV_VERSION. but it always used
* Mon Nov 20 2017 lbeltrame@kde.org
- Update to 17.11.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12-beta.php
- Changes since 17.08.3:
  * Too many changes to list here
* Thu Nov  9 2017 lbeltrame@kde.org
- Update to 17.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.3.php
- Changes since 17.08.2:
  * None
* Mon Oct 16 2017 lbeltrame@kde.org
- Update to 17.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.2.php
- Changes since 17.08.1:
  * None
* Thu Sep  7 2017 lbeltrame@kde.org
- Update to 17.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.1.php
- Changes since 17.08.0:
  * remove full stop and add missing comment, required by appstream data http://metadata.neon.kde.org/appstream/html/xenial/main/issues/kaddressbook.html
  * src/kaddressbookui.rc - fix the menu order for consistency
* Fri Aug 11 2017 christophe@krop.fr
- Update to KDE Applications 17.08.0
  * New feature release
  * https://www.kde.org/announcements/announce-applications-17.08.0.php
- Changes since 17.04.3 :
- Too many changes to list here
* Sat Aug  5 2017 christophe@krop.fr
- Update to KDE Applications 17.07.90
  * KDE Applications 17.07.90
  * https://www.kde.org/announcements/announce-applications-17.08-rc.php
* Sat Jul 15 2017 lbeltrame@kde.org
- Update to 17.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.3.php
- Changes since 17.04.2:
  * None
* Wed Jun  7 2017 lbeltrame@kde.org
- Update to 17.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.2.php
- Changes since 17.04.1:
  * None
* Wed May 17 2017 lbeltrame@kde.org
- Update to 17.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.1.php
- Changes since 17.04.0:
  * None
* Sun Apr 16 2017 lbeltrame@kde.org
- Update to 17.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.0.php
- Changes since 17.03.90:
  * None
* Wed Apr 12 2017 lbeltrame@kde.org
- Update to 17.03.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04-rc.php
- Changes since 17.03.80:
  * None
* Sat Mar 25 2017 lbeltrame@kde.org
- Update to 17.03.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04-beta.php
- Changes since 16.12.3:
  * Too many changes to list here
* Thu Mar  9 2017 lbeltrame@kde.org
- Update to 16.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-16.12.3.php
- Changes since 16.12.2:
  * None
* Thu Feb  9 2017 lbeltrame@kde.org
- Update to KDE Applications 16.12.2
  * KDE Applications 16.12.2
  * https://www.kde.org/announcements/announce-applications-16.12.2.php
* Sat Jan 28 2017 wbauer@tmo.at
- BuildRequire prison-qt5-devel instead of libprison-devel (which
  is the KDE4 version) to enable the barcode features
* Sat Jan 14 2017 lbeltrame@kde.org
- - Update to KDE Applications 16.12.1
  * KDE Applications 16.12.1
  * https://www.kde.org/announcements/announce-applications-16.12.1.php
* Tue Dec 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.12.0
  * KDE Applications 16.12.0
  * https://www.kde.org/announcements/announce-applications-16.12.0.php
* Thu Dec  8 2016 lbeltrame@kde.org
- Update license as pointed out by legal review
* Sat Dec  3 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.11.90
  * KDE Applications 16.12.0 RC
  * https://www.kde.org/announcements/announce-applications-16.12-rc.php
* Tue Nov 29 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.11.80
  * KDE Applications 16.12.0 Beta
  * https://www.kde.org/announcements/announce-applications-16.12-beta.php
* Sun Nov 27 2016 tittiatcoke@gmail.com
- Update spec-files to be consistent wiht KA
